import { unique } from '../../util/array.js';
import { findShebang, mergeRuleIdsAndDescription, parseDisableComment, toCommentText, } from '../../util/eslint.js';
import { notEmpty } from '../../util/type-check.js';
function findDisableCommentPerFile(commentsInFile) {
    return commentsInFile.map(parseDisableComment).find((comment) => (comment === null || comment === void 0 ? void 0 : comment.scope) === 'file');
}
function generateFix(context, description) {
    var _a;
    const ruleIdsToDisable = unique(context.messages.map((message) => message.ruleId).filter(notEmpty));
    if (ruleIdsToDisable.length === 0)
        return null;
    const commentsInFile = context.sourceCode.getAllComments();
    const disableCommentPerFile = findDisableCommentPerFile(commentsInFile);
    if (disableCommentPerFile) {
        const text = toCommentText({
            type: 'Block',
            scope: 'file',
            ...mergeRuleIdsAndDescription(disableCommentPerFile, {
                ruleIds: ruleIdsToDisable,
                description,
            }),
        });
        return context.fixer.replaceTextRange(disableCommentPerFile.range, text);
    }
    else {
        const text = toCommentText({ type: 'Block', scope: 'file', ruleIds: ruleIdsToDisable, description }) + '\n';
        const shebang = findShebang(context.sourceCode.text);
        // if shebang exists, insert comment after shebang
        return context.fixer.insertTextAfterRange((_a = shebang === null || shebang === void 0 ? void 0 : shebang.range) !== null && _a !== void 0 ? _a : [0, 0], text);
    }
}
/**
 * Create fix to add disable comment per file.
 */
export function createFixToDisablePerFile(context, args) {
    const fix = generateFix(context, args.description);
    return fix ? [fix] : [];
}
//# sourceMappingURL=disable-per-file.js.map