import { groupBy, unique } from '../../util/array.js';
import { mergeRuleIdsAndDescription, parseDisableComment, toCommentText } from '../../util/eslint.js';
import { notEmpty } from '../../util/type-check.js';
function findDisableCommentPerLine(commentsInFile, line) {
    const commentsInPreviousLine = commentsInFile.filter((comment) => { var _a; return ((_a = comment.loc) === null || _a === void 0 ? void 0 : _a.start.line) === line - 1; });
    return commentsInPreviousLine.map(parseDisableComment).find((comment) => (comment === null || comment === void 0 ? void 0 : comment.scope) === 'next-line');
}
function generateFixPerLine(context, description, line, messagesInLine) {
    const ruleIdsToDisable = unique(messagesInLine.map((message) => message.ruleId).filter(notEmpty));
    if (ruleIdsToDisable.length === 0)
        return null;
    const commentsInFile = context.sourceCode.getAllComments();
    const disableCommentPerLine = findDisableCommentPerLine(commentsInFile, line);
    if (disableCommentPerLine) {
        const text = toCommentText({
            type: 'Block',
            scope: 'next-line',
            ...mergeRuleIdsAndDescription(disableCommentPerLine, {
                ruleIds: ruleIdsToDisable,
                description,
            }),
        });
        return context.fixer.replaceTextRange(disableCommentPerLine.range, text);
    }
    else {
        const headNodeIndex = context.sourceCode.getIndexFromLoc({ line: line, column: 0 });
        const headNode = context.sourceCode.getNodeByRangeIndex(headNodeIndex);
        if (headNode === null)
            return null; // For some reason, it seems to be null sometimes.
        // eslint-disable-next-line @typescript-eslint/no-explicit-any
        if (headNode.type === 'JSXText') {
            const commentText = toCommentText({ type: 'Block', scope: 'next-line', ruleIds: ruleIdsToDisable, description });
            return context.fixer.insertTextBeforeRange([headNodeIndex, headNodeIndex], '{' + commentText + '}\n');
        }
        else {
            const commentText = toCommentText({ type: 'Line', scope: 'next-line', ruleIds: ruleIdsToDisable, description });
            return context.fixer.insertTextBeforeRange([headNodeIndex, headNodeIndex], commentText + '\n');
        }
    }
}
/**
 * Create fix to add disable comment per line.
 */
export function createFixToDisablePerLine(context, args) {
    const lineToMessages = groupBy(context.messages, (message) => message.line);
    const fixes = [];
    for (const [line, messagesInLine] of lineToMessages) {
        const fix = generateFixPerLine(context, args.description, line, messagesInLine);
        if (fix)
            fixes.push(fix);
    }
    return fixes;
}
//# sourceMappingURL=disable-per-line.js.map